@@ -112,7 +112,7 @@ class EditsManager(object):
                 # Rather than be self-referential and set, say, fact.orig_fact = fact,
                 # we use a magic placeholder, 0, that happens to be non-truthy, and
                 # indicates that this fact is the original, unedited copy of itself.
-                fact.orig_fact = 0
+                fact.orig_fact = 0  # As opposed to None, means original, unedited copy.
         self.conjoined.add_facts(more_facts)
 
     def setup_edit_facts(self, edit_facts):
@@ -383,7 +383,7 @@ class EditsManager(object):
             # FIXME: When latest_fact is None => what's empty carousel state?
             self.add_facts([latest_fact])
 
-        return _standup()
+        _standup()
 
     # ***
 
@@ -554,21 +554,24 @@ class EditsManager(object):
             for edit_fact in edited_facts:
                 new_fact = save_edited_fact(edit_fact, ignore_pks)
                 if new_fact is None:
-                    # Something went wrong, and we displayed an error.
-                    # Return now, and leave the store in a Bad State.
-                    # Users are encouraged to keep their data stores
-                    # under revision control so that they can recover
-                    # from blunders such as these. And we should make
-                    # sure our code is tough and resilient and stable.
-                    # I.e., we don't need to bother handling this error
-                    # better; just don't cause an error.
-                    return None, None  # Short-circuit return!
+                    return save_edited_fact_failed()
                 saved_facts.append(new_fact)
                 if edit_fact is self.curr_fact:
                     keep_fact = new_fact
                 affirm_saved_edited_fact(edit_fact, new_fact)
             return keep_fact, saved_facts
 
+        def save_edited_fact_failed():
+            # Something went wrong, and we displayed an error.
+            # Return now, and leave the store in a Bad State.
+            # Users are encouraged to keep their data stores
+            # under revision control so that they can recover
+            # from blunders such as these. And we should make
+            # sure our code is tough and resilient and stable.
+            # I.e., we don't need to bother handling this error
+            # better; just don't cause an error.
+            return None, None  # Short-circuit return!
+
         def save_edited_fact(edit_fact, ignore_pks):
             # (lb): SIMILAR: edits_manager.save_edited_fact, create.save_fact.
             if edit_fact.pk and edit_fact.pk < 0:
@@ -601,7 +604,7 @@ class EditsManager(object):
             #   will be rebuilt from scratch.)
             if edit_fact.pk:
                 # PK is different for saved fact, and old fact is marked deleted;
-                #   except for ongoing Fact, which retains its ID.
+                #   except for active (an ongoing) Fact, which retains its ID.
                 if edit_fact.pk != new_fact.pk:
                     self.controller.affirm(new_fact.pk >= edit_fact.pk)
                     self.controller.affirm(edit_fact.deleted)
