@@ -50,28 +50,28 @@ def make_bindings(key_bonds):
 
 # ***
 
-def key_bonds_widget_focus(handler):
+def key_bonds_widget_focus(action_map):
     key_bonds_widget_focus = [
-        KeyBond('tab', action=handler.focus_next),
-        KeyBond('s-tab', action=handler.focus_previous),
+        KeyBond('tab', action=action_map.focus_next),
+        KeyBond('s-tab', action=action_map.focus_previous),
         # Bindings to edit time are always available (and toggle focus when repeated).
-        KeyBond('s', action=handler.edit_time_start),
-        KeyBond('e', action=handler.edit_time_end),
+        KeyBond('s', action=action_map.edit_time_start),
+        KeyBond('e', action=action_map.edit_time_end),
     ]
     return key_bonds_widget_focus
 
 
 # ***
 
-def key_bonds_save_and_quit(handler):
+def key_bonds_save_and_quit(action_map):
     key_bonds_save_and_quit = [
         # Save Facts command is where you'd expect it.
-        KeyBond('c-s', action=handler.save_edited_and_live),
-        KeyBond('c-w', action=handler.save_edited_and_exit),
+        KeyBond('c-s', action=action_map.save_edited_and_live),
+        KeyBond('c-w', action=action_map.save_edited_and_exit),
         # User can soft-cancel if they have not edited.
-        KeyBond('q', action=handler.cancel_softly),
+        KeyBond('q', action=action_map.cancel_softly),
         # User can always real-quit, but prompted if edits.
-        KeyBond('c-q', action=handler.cancel_command),
+        KeyBond('c-q', action=action_map.cancel_command),
         # NOTE: Using 'escape' to exit is slow because PPT waits to
         #       see if escape sequence follows (which it wouldn't, after
         #       an 'escape', but meta-combinations start with an escape).
@@ -79,14 +79,15 @@ def key_bonds_save_and_quit(handler):
         # Note that 'escape' here is the actual ESCape key,
         # and not to be confused with the meta key character,
         # e.g., using ('escape', 'm') to capture Alt-m (m-m).
-        KeyBond('escape', action=handler.cancel_softly),
+        KeyBond('escape', action=action_map.cancel_softly),
     ]
     return key_bonds_save_and_quit
 
 
 # ***
 
-def key_bonds_edit_time(handler):
+def key_bonds_edit_time(zone_details):
+    handler = zone_details
     key_bonds_edit_time = [
         KeyBond('enter', action=handler.editable_text_enter),
         KeyBond('d', action=handler.toggle_focus_description),
@@ -99,7 +100,8 @@ def key_bonds_edit_time(handler):
 
 # ***
 
-def key_bonds_undo_redo(handler):
+def key_bonds_undo_redo(action_map_or_zone_details):
+    handler = action_map_or_zone_details
     key_bonds_undo_redo = [
         # Vim maps Ctrl-z and Ctrl-y for undo and redo;
         # and u/U to undo count/all and Ctrl-R to redo (count).
@@ -118,34 +120,34 @@ def key_bonds_undo_redo(handler):
 
 # ***
 
-def key_bonds_normal(handler):
+def key_bonds_normal(action_map):
     key_bonds_normal = [
-        KeyBond('?', action=handler.rotate_help),
+        KeyBond('?', action=action_map.rotate_help),
         #
         # 2020-03-30: (lb): Was using PPT-HOTH fork and had m- mappings, e.g.,
-        #   KeyBond('m-=', action=handler.dev_breakpoint),
-        KeyBond((Keys.Escape, '='), action=handler.dev_breakpoint),
+        #   KeyBond('m-=', action=action_map.dev_breakpoint),
+        KeyBond((Keys.Escape, '='), action=action_map.dev_breakpoint),
         #
-        KeyBond('j', action=handler.jump_fact_dec),
-        KeyBond('k', action=handler.jump_fact_inc),
-        KeyBond(Keys.Left, action=handler.jump_fact_dec),
-        KeyBond(Keys.Right, action=handler.jump_fact_inc),
+        KeyBond('j', action=action_map.jump_fact_dec),
+        KeyBond('k', action=action_map.jump_fact_inc),
+        KeyBond(Keys.Left, action=action_map.jump_fact_dec),
+        KeyBond(Keys.Right, action=action_map.jump_fact_inc),
         #
-        KeyBond('J', action=handler.jump_day_dec),
-        KeyBond('K', action=handler.jump_day_inc),
+        KeyBond('J', action=action_map.jump_day_dec),
+        KeyBond('K', action=action_map.jump_day_inc),
         # NOTE: It's not, say, 'm-left', but Escape-Arrow.
         # Ahahahaha, alt-arrows are special to Terminator, durp!
-        KeyBond((Keys.Escape, Keys.Left), action=handler.jump_day_dec),
-        KeyBond((Keys.Escape, Keys.Right), action=handler.jump_day_inc),
+        KeyBond((Keys.Escape, Keys.Left), action=action_map.jump_day_dec),
+        KeyBond((Keys.Escape, Keys.Right), action=action_map.jump_day_inc),
         #
-        KeyBond(('g', 'g'), action=handler.jump_rift_dec),
-        KeyBond('G', action=handler.jump_rift_inc),
+        KeyBond(('g', 'g'), action=action_map.jump_rift_dec),
+        KeyBond('G', action=action_map.jump_rift_inc),
         # (lb): Not every Vim key needs to be mapped, e.g.,
-        #  KeyBond('M', action=handler.jump_fact_midpoint),
+        #  KeyBond('M', action=action_map.jump_fact_midpoint),
         # seems capricious, i.e., why implement if not just because we can?
         #
-        KeyBond('h', action=handler.cursor_up_one),
-        KeyBond('l', action=handler.cursor_down_one),
+        KeyBond('h', action=action_map.cursor_up_one),
+        KeyBond('l', action=action_map.cursor_down_one),
         #
         # FIXME: Oh, maybe make complicated handlers rather than hacking PPT lib?
         # NOTE: If you want to see how key presses map to KeyPresses, try:
@@ -157,25 +159,25 @@ def key_bonds_normal(handler):
         # ((lb): There might be a different way to do this... not sure.)
         KeyBond(  # Alt-UP
             ('escape', '[', '1', ';', '4', 'A'),
-            action=handler.ignore_key_press_noop,
+            action=action_map.ignore_key_press_noop,
         ),
         KeyBond(  # Alt-DOWN
             ('escape', '[', '1', ';', '4', 'B'),
-            action=handler.ignore_key_press_noop,
+            action=action_map.ignore_key_press_noop,
         ),
         KeyBond(  # Alt-RIGHT [bunch of snowflakes]
             ('escape', '[', '1', ';', '4', 'C'),
-            action=handler.ignore_key_press_noop,
+            action=action_map.ignore_key_press_noop,
         ),
         KeyBond(  # Alt-LEFT
             ('escape', '[', '1', ';', '4', 'D'),
-            action=handler.ignore_key_press_noop,
+            action=action_map.ignore_key_press_noop,
         ),
         #
-        KeyBond('pageup', action=handler.scroll_up),
-        KeyBond('pagedown', action=handler.scroll_down),
-        KeyBond('home', action=handler.scroll_top),
-        KeyBond('end', action=handler.scroll_bottom),
+        KeyBond('pageup', action=action_map.scroll_up),
+        KeyBond('pagedown', action=action_map.scroll_down),
+        KeyBond('home', action=action_map.scroll_top),
+        KeyBond('end', action=action_map.scroll_bottom),
         #
         # FIXME/BACKLOG: Search feature. E.g., like Vim's /:
         #   KeyBond('/', action=zone_lowdown.start_search),
@@ -187,54 +189,54 @@ def key_bonds_normal(handler):
 
 # ***
 
-def key_bonds_update(handler):
+def key_bonds_update(action_map):
     key_bonds_update = [
         # Raw Fact Editing. With a Capital E.
-        KeyBond('E', action=handler.edit_fact),
+        KeyBond('E', action=action_map.edit_fact),
         # Edit act@gory, description, and tags using prompt__awesome.
         # (lb): This is pretty cool. prompt_awesome was built first,
         # and then I got comfortable with PPT and built the Carousel,
         # and then I was able to stick one inside the other, and it's
         # just awesome awesome now.
-        KeyBond('a', action=handler.edit_actegory),
-        KeyBond('d', action=handler.edit_description),
-        KeyBond('t', action=handler.edit_tags),
+        KeyBond('a', action=action_map.edit_actegory),
+        KeyBond('d', action=action_map.edit_description),
+        KeyBond('t', action=action_map.edit_tags),
         #
-        KeyBond('s-left', action=handler.edit_time_decrement_start),
-        KeyBond('s-right', action=handler.edit_time_increment_start),
-        KeyBond('c-left', action=handler.edit_time_decrement_end),
-        KeyBond('c-right', action=handler.edit_time_increment_end),
+        KeyBond('s-left', action=action_map.edit_time_decrement_start),
+        KeyBond('s-right', action=action_map.edit_time_increment_start),
+        KeyBond('c-left', action=action_map.edit_time_decrement_end),
+        KeyBond('c-right', action=action_map.edit_time_increment_end),
         # FIXME/2019-01-21: Can you check if running in Terminator
         #  and warn-tell user. And/Or: Customize Key Binding feature.
         # In Terminator: Shift+Ctrl+Left/+Right: Resize the terminal left/right.
         #  (lb): I've disabled the 2 bindings in Terminator,
         #   so this works for me... so fixing it is a low priority!
-        KeyBond('s-c-left', action=handler.edit_time_decrement_both),
-        KeyBond('s-c-right', action=handler.edit_time_increment_both),
+        KeyBond('s-c-left', action=action_map.edit_time_decrement_both),
+        KeyBond('s-c-right', action=action_map.edit_time_increment_both),
         #
         # 2020-03-30: (lb): Was using PPT-HOTH fork and had m- mappings, e.g.,
-        #   KeyBond('m-p', action=handler.fact_split),
-        #   KeyBond('m-e', action=handler.fact_erase),
-        #   KeyBond(('m-m', Keys.Left), action=handler.fact_merge_prev),
-        #   KeyBond(('m-m', Keys.Right), action=handler.fact_merge_next),
-        KeyBond((Keys.Escape, 'p'), action=handler.fact_split),
-        KeyBond((Keys.Escape, 'e'), action=handler.fact_erase),
-        KeyBond((Keys.Escape, 'm', Keys.Left), action=handler.fact_merge_prev),
-        KeyBond((Keys.Escape, 'm', Keys.Right), action=handler.fact_merge_next),
+        #   KeyBond('m-p', action=action_map.fact_split),
+        #   KeyBond('m-e', action=action_map.fact_erase),
+        #   KeyBond(('m-m', Keys.Left), action=action_map.fact_merge_prev),
+        #   KeyBond(('m-m', Keys.Right), action=action_map.fact_merge_next),
+        KeyBond((Keys.Escape, 'p'), action=action_map.fact_split),
+        KeyBond((Keys.Escape, 'e'), action=action_map.fact_erase),
+        KeyBond((Keys.Escape, 'm', Keys.Left), action=action_map.fact_merge_prev),
+        KeyBond((Keys.Escape, 'm', Keys.Right), action=action_map.fact_merge_next),
     ]
     return key_bonds_update
 
 
-def key_bonds_clipboard(handler):
+def key_bonds_clipboard(action_map):
     key_bonds_clipboard = [
         #
-        KeyBond('c-c', action=handler.fact_copy_fact),
-        KeyBond('c-x', action=handler.fact_cut),
-        KeyBond('c-v', action=handler.fact_paste),
+        KeyBond('c-c', action=action_map.fact_copy_fact),
+        KeyBond('c-x', action=action_map.fact_cut),
+        KeyBond('c-v', action=action_map.fact_paste),
         #
-        KeyBond(('A', 'c-c'), action=handler.fact_copy_activity),
-        KeyBond(('T', 'c-c'), action=handler.fact_copy_tags),
-        KeyBond(('D', 'c-c'), action=handler.fact_copy_description),
+        KeyBond(('A', 'c-c'), action=action_map.fact_copy_activity),
+        KeyBond(('T', 'c-c'), action=action_map.fact_copy_tags),
+        KeyBond(('D', 'c-c'), action=action_map.fact_copy_description),
     ]
     return key_bonds_clipboard
 
