@@ -48,6 +48,7 @@ class ZoneDetails(
 ):
     """"""
     def __init__(self, carousel):
+        super(ZoneDetails, self).__init__()
         self.carousel = carousel
         self.active_widgets = None
         # Convenience attrs.
@@ -77,21 +78,16 @@ class ZoneDetails(
             self.orig_val = orig_val
             self.mouse_handler = mouse_handler
 
-    def standup(self):
-        pass
-
     # ***
 
-    def rebuild_viewable(self):
+    def standup(self):
         """"""
-        def _rebuild_viewable():
+        def _standup():
             # A couple convenience attrs.
             self.zone_manager = self.carousel.zone_manager
             self.zone_content = self.carousel.zone_manager.zone_content
             assemble_children()
             self.details_container = build_container()
-            self.refresh_all_children()
-            return self.details_container
 
         def assemble_children():
             self.children = []
@@ -190,7 +186,14 @@ class ZoneDetails(
 
         # ***
 
-        return _rebuild_viewable()
+        _standup()
+
+    # ***
+
+    def rebuild_viewable(self):
+        """"""
+        self.refresh_all_children()
+        return self.details_container
 
     # ***
 
@@ -218,7 +221,7 @@ class ZoneDetails(
             # somehow reports lexer.__class__: abc.ABCMeta. Fortunately,
             # rather than trying to explain how the lexer object gets
             # converted into some meta wrapper thing, we can use a builtin
-            # lexer that simple style the input text.
+            # lexer that simply styles the input text.
             text_area = TextArea(
                 height=1,
                 lexer=SimpleLexer(style='class:value-focus'),
@@ -371,7 +374,7 @@ class ZoneDetails(
         self.add_stylable_classes_header_values_focus(keyval_parts, set_focus)
 
     def add_stylable_classes_header_titles(self, keyval_parts, set_focus=None):
-        # key_parts is a list of Labels (from make_header_label_parts).
+        # keyval_parts.key_parts is a list of Labels (from make_header_label_parts).
         # - The first item is the left column padding. E.g.: '  '.
         # - The second item is the meta label and the ...-padding.
         # - The third item is the middle column, ' : ', before the value.
@@ -592,7 +595,7 @@ class ZoneDetails(
     #   - Probably use footer to show message; but could instead use popup modal.
 
     # FIXME/BACKLOG/2019-01-21: Need way to cancel after editing time:
-    #   Possible key binding: ctrl-q, escape, q, etc.
+    #   Possible key binding: Ctrl-q, ESC, q, etc.
 
     @catch_action_exception
     def editable_text_enter(self, event=None, passive=False):
@@ -766,7 +769,7 @@ class ZoneDetails(
     @catch_action_exception
     # SKIP: @ZoneContent.Decorators.reset_showing_help
     def toggle_focus_description(self, event):
-        self.zone_manager.toggle_focus_time(self.zone_manager.content_control)
+        self.zone_manager.toggle_focus_time_widget(self.zone_manager.content_control)
 
     @catch_action_exception
     def undo_command(self, event):
