@@ -71,6 +71,7 @@ class ZoneManager(object):
         self.zone_details.standup()
         self.zone_content.standup()
         self.zone_lowdown.standup()
+        self.assemble_focus_jumps()
 
     # ***
 
@@ -236,7 +237,6 @@ class ZoneManager(object):
         """
         self.reset_diff_fact()
         self.rebuild_containers()
-        self.assemble_focus_jumps()
         self.selectively_refresh()
         self.carousel.controller.client_logger.debug(_('rebuilt and refreshed'))
 
@@ -305,28 +305,18 @@ class ZoneManager(object):
         self.focus_move(lambda index: (index or len(self.focus_chain)) - 1)
 
     def focus_move(self, index_f):
-        # NOTE: PPT has focus_next(event), which can cycle through focusable
+        # NOTE: PTK has focus_next(event), which can cycle through focusable
         #       containers, but the edit-time controls are on-demand, so we
         #       do this manually.
         curr_control = self.layout.current_control
         try:
             defocused = self.focus_surround[curr_control](focus=False)
-        except Exception as err:
-            # 2019-11-27: (lb): This method tossed a KeyError earlier this year
-            # -- last winter, before a nine month development hiatus -- so then
-            # I added this catch. And I never reproduced the issue. Though I am
-            # not convinced it's resolved. And this code is useful to keep: why
-            # not gracefully recover from an error rather than dying. For post-
-            # erity, the key without an entry was reported as:
-            #  <BufferControl buffer=<Buffer(name='', text='2019-01-23 1...')...
-            self.carousel.controller.client_logger.error(
-                _('focus_move failed: {}').format(str(err))
-            )
+        except Exception as err:  # noqa: F841 local variable ... never used
+            # 2020-04-07: See d4d12cc3. This should be fixed!
             self.carousel.controller.affirm(False)  # REPL if dev.catch_errors.
             return
         if not defocused:
             return
-        curr_index = self.focus_chain.index(curr_control)
         curr_index = self.focus_index(curr_control)
         next_index = index_f(curr_index)
         next_control = self.focus_chain[next_index]
@@ -356,14 +346,14 @@ class ZoneManager(object):
     @catch_action_exception
     # SKIP: @ZoneContent.Decorators.reset_showing_help
     def toggle_focus_time_end(self, event):
-        self.toggle_focus_time(self.widget_control_time_end)
+        self.toggle_focus_time_widget(self.widget_control_time_end)
 
     @catch_action_exception
     # SKIP: @ZoneContent.Decorators.reset_showing_help
     def toggle_focus_time_start(self, event):
-        self.toggle_focus_time(self.widget_control_time_start)
+        self.toggle_focus_time_widget(self.widget_control_time_start)
 
-    def toggle_focus_time(self, time_control):
+    def toggle_focus_time_widget(self, time_control):
         focus = self.layout.current_control is not time_control
         if focus:
             which_index = self.focus_index(time_control)
